@@ -12,7 +12,7 @@ pub fn main() {
     let my_state = MyState::new("Hello, World!");
 
     let context = ContextBuilder::new().build();
-    WolfEngineBuilder::with_default_game_loop()
+    WolfEngineBuilder::with_default_scheduler()
         .build(context)
         .run(Box::from(my_state));
 }
