@@ -6,38 +6,38 @@ use winit::{
 };
 
 use crate::{
-    game_loop::{FixedUpdateGameLoop, GameLoop},
+    scheduler::{FixedUpdateScheduler, Scheduler},
     Context, State, StateStack,
 };
 
 /// Provides the core functionality of the engine.
 ///
 /// `WolfEngine` is, as the name suggests, the core of the game engine.  It provides some common
-/// behavior such as: Running the main loop (utilizing a [GameLoop] for timing control), cleanly
+/// behavior such as: Running the main loop (utilizing a [Scheduler] for timing control), cleanly
 /// shutting down, and holding ownership over the [Context] object.
 ///
 /// The engine tries to only include functionality that is common to all `WolfEngine` projects.  
 /// Anything else should live on the [Context] object instead.
-pub struct WolfEngine<Loop: GameLoop> {
+pub struct WolfEngine<Schedule: Scheduler> {
     context: Context,
-    game_loop: Loop,
+    scheduler: Schedule,
     state_stack: StateStack,
 }
 
-impl<Loop: GameLoop> WolfEngine<Loop> {
+impl<Loop: Scheduler> WolfEngine<Loop> {
     pub fn run(mut self, initial_state: Box<dyn State>) {
         self.state_stack.push(initial_state);
         while !self.state_stack.is_empty() {
-            self.game_loop
+            self.scheduler
                 .update(&mut self.context, &mut self.state_stack);
-            self.game_loop
+            self.scheduler
                 .render(&mut self.context, &mut self.state_stack);
         }
     }
 }
 
 #[cfg(feature = "window")]
-impl<Loop: GameLoop> WolfEngine<Loop> {
+impl<Loop: Scheduler> WolfEngine<Loop> {
     pub fn run_with_event_loop(mut self, initial_state: Box<dyn State>, event_loop: EventLoop<()>) {
         self.state_stack.push(initial_state);
         self.run_event_loop(event_loop);
@@ -47,11 +47,11 @@ impl<Loop: GameLoop> WolfEngine<Loop> {
         event_loop.run_return(|event, _window, control_flow| {
             match event {
                 Event::MainEventsCleared => {
-                    self.game_loop
+                    self.scheduler
                         .update(&mut self.context, &mut self.state_stack);
                 }
                 Event::RedrawRequested(_) => {
-                    self.game_loop
+                    self.scheduler
                         .render(&mut self.context, &mut self.state_stack);
                 }
                 Event::WindowEvent {
@@ -70,31 +70,31 @@ impl<Loop: GameLoop> WolfEngine<Loop> {
 }
 
 /// Build an instance of [WolfEngine].
-pub struct WolfEngineBuilder<Loop: GameLoop> {
-    game_loop: Loop,
+pub struct WolfEngineBuilder<Loop: Scheduler> {
+    scheduler: Loop,
 }
 
-impl WolfEngineBuilder<FixedUpdateGameLoop> {
-    pub fn with_default_game_loop() -> Self {
+impl WolfEngineBuilder<FixedUpdateScheduler> {
+    pub fn with_default_scheduler() -> Self {
         Self {
-            game_loop: Default::default(),
+            scheduler: Default::default(),
         }
     }
 
-    pub fn with_fixed_game_loop(game_loop: FixedUpdateGameLoop) -> Self {
-        Self { game_loop }
+    pub fn with_fixed_scheduler(scheduler: FixedUpdateScheduler) -> Self {
+        Self { scheduler }
     }
 }
 
-impl<Loop: GameLoop> WolfEngineBuilder<Loop> {
-    pub fn with_custom_game_loop(game_loop: Loop) -> Self {
-        Self { game_loop }
+impl<Loop: Scheduler> WolfEngineBuilder<Loop> {
+    pub fn with_custom_scheduler(scheduler: Loop) -> Self {
+        Self { scheduler }
     }
 
     pub fn build(self, context: Context) -> WolfEngine<Loop> {
         WolfEngine {
             context,
-            game_loop: self.game_loop,
+            scheduler: self.scheduler,
             state_stack: StateStack::new(),
         }
     }
@@ -109,7 +109,7 @@ mod wolf_engine_tests {
     #[test]
     fn should_run_the_state() {
         let context = ContextBuilder::new().build();
-        let wolf_engine = WolfEngineBuilder::with_default_game_loop().build(context);
+        let wolf_engine = WolfEngineBuilder::with_default_scheduler().build(context);
         let mut state = MockState::new();
         state
             .expect_update()
